
# Type: integer


An integer

URI: [https://w3id.org/biolink/vocab/biolinkml:types/Integer](https://w3id.org/biolink/vocab/biolinkml:types/Integer)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **int** |
